/*
 * Web Designer
 * Copyright (C) 1999-2000  LADISLAS Willhem
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 * 
 * Author's email : zillprog@freesurf.fr
 * 
 * snailmail : 
 * LADISLAS Willhem
 * 2, rue du Serpolet
 * 95490 VAUREAL
 * FRANCE
 */

#include <gtk/gtk.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <unistd.h>
#include <ctype.h>
#include <gdk/gdkkeysyms.h>

#include "my_intl.h"
#include "config.h"
#include "config_extra.h"
#include "constants.h"

/*
 * headers of advanced.c
 */

void insert_text_and_move_cursor (GtkWidget * widget, guint Opcode);

/*
 * headers of color.c
 */
 
GtkWidget *color_dialog;
void color_insert_dialog (void);

/*
 * headers of common.c
 */
void insert_path_exec (GtkWidget * w, GtkFileSelection * fs);
void dialog_insert_path (void);
void tag_insert_exec (GtkWidget * widget, int Opcode);
void repeat_tag (void);
void choose_H (void);
void html_comment (void);

/*
 * headers of compact.c
 */
void compact_file (GtkWidget * w, int Opcode);

/*
 * headers of doc.c
 */
void refresh_clist (void);
void coord (GtkWidget * widget, gpointer data);
void gtk_swpg (void);
void clist_selection_made (GtkWidget * clist, gint row, gint column, GdkEventButton * event, gpointer data);
void init_clist (void);

/*
 * headers of edition.c
 */
void change_selection_case (GtkWidget * widget, guint Opcode);
void remove_tags (void);
void inst_txt (GtkEditable * editable, const char *text, int len, int *pos, gpointer data);
void clipboard_actions (GtkWidget * w, guint Op);
void go_line (void);

/*
 * headers of file.c
 */
void edit_file_exec (void);
void import_file_exec (GtkWidget * w, GtkFileSelection * fs);
void import_file_dialog (void);
void file_modified (void);
void savefile (void);
void close_primary2 (void);
void close_primary (void);
void close_file (void);
void close_all_files (void);
void filesaveas (GtkWidget * w, GtkFileSelection * fs);
void dialogsaveas (void);
void text_toggle_editable (void);
void text_toggle_word_wrap (void);
void nfile (GtkWidget * w, GtkFileSelection * fs);
int openfile2 (gchar * filepath, gboolean nouveau, gboolean prj);
void new_html_file (void);
void newfile (void);
void openfile (void);

/*
 * headers of getline.c
 */
char *get_full_line ( FILE *fptr );
char *const2str ( char *string );

/*
 * headers of menu.c
 */

void get_main_menu (GtkWidget *window,  GtkWidget **menubar);
void add_menu_item (GtkWidget *menubar, GtkItemFactoryEntry *menuitem);

/*
 * headers of misc.c
 */
void tab_window_toggle (void);
void widget_style (GtkWidget * wgt);
char *getpath (char *path);
void display_file_info (void);
void print_file (void);
void helpwindow (void);
void toggle_tab_pos (GtkWidget * w, int Opcode);
void insert_date (void);
void insert_date_exec (GtkWidget * widget, gpointer data);
void terminal (void);
void new_window (void);
void merror (gchar * label);
void ask_for (gchar * label);
void netscape_view (void);
#ifdef HAVE_LIBGTKXMHTML
void int_view (void);
#endif
gint button_press (GtkWidget * widget, GdkEvent * event);
gint button_press_coord (GtkWidget * widget, GdkEvent * event);
GtkWidget *new_pixmap (int type, GdkWindow * window, GdkColor * background);
void insert_lbl (GtkWidget * wid, gchar * labe);
void insert_space (GtkWidget * wid);
char *getname (char *path);
char *getext (char *path);
void updatefilelist (short num);
void close_application (GtkWidget * widget, gpointer data);
void about (void);

/*
 * headers of navigation.c
 */

void move_notebook_page (GtkWidget * widget, int Opcode);
void move_in_document (GtkWidget * widget, int Opcode);

/*
 * headers of page.c
 */
void init_doctypelist (void);
void load_meta_info (void);

/*
 * headers of preferences.c
 */
struct {
	gchar *browser_command;
	gchar *tab_position;
	gchar *terminal;
	gchar *print_command;

	gboolean show_tips;
	gboolean splash_screen;

	char *recent_files[12]; /* Only 10 is used, but let's have 12. Just in case... */
	gint max_recent_files;
} preferences;

void display_preferences_dialog (void);
void init_preferences (void);
void done_preferences (void);
void load_preferences (void);
void save_preferences (void);
void apply_preferences (void);

/*
 * headers of project.c
 */
void add_afile_prj_dialog (void);
void new_project (void);
void save_project_under_dialog (void);
void save_project (GtkWidget * w, int opcode);
void add_file (void);
void remove_file (void);
void remove_file2 (void);
void open_all_prjfiles (void);
void open_project (GtkWidget * w, GtkFileSelection * fs);
int open_project2 (gchar * prjnm);
void open_project_dialog (void);
void close_all_prjfiles (void);
void close_project (void);

/*
 * headers of recent.c
 */
void recent_display ( void );
void recent_add ( char *filename );

/*
 * headers of tips.c
 */
void display_tip_window (void);

/*
 * headers of toolbar.c
 */
GtkWidget *load_static_toolbar (void);
void load_first_toolbar (void);
void init_popmenu (void);

/*
 * webdesigner main headers
 */

/*
 * Widgets utiliss 
 */
GtkWidget *menubar;
GtkWidget *window;
GtkWidget *dialog_window;
GtkWidget *filew;
GtkWidget *status_bar;
GtkWidget *file_status_bar;
GtkWidget *coord_status_bar;
GtkWidget *notebook;
GtkWidget *notebook0;
GtkWidget *main_vbox;
GtkWidget *clist;
GtkWidget *clistdialog;
GtkWidget *clistvbox;
GtkWidget *popmenu;
GtkWidget *popmenu2;
GtkWidget *clist_lbl;
GtkWidget *mainmenubar;
GtkWidget *tag_window;
GtkWidget *hbox2;
gboolean tab_activ;

GdkColormap *cmap;
GdkColor color;
GdkColor red;
GdkColor black;
GdkColor blue;
GdkColor green;
GdkColor marron;
GdkColor colour;
GdkColor savecol;

GdkFont *fixed_font;
GdkFont *fixed_font_bold;

GdkPixmap *pixm;

short editok, wrapok;
short curfile, numfileopened;
gint context_id;
gint clist_row2;
char projectname[255];
int lasttag_nb;
gint numprjfiles;
gboolean acc;
gboolean prjsaved;
gboolean prjopnd;
gboolean prjnew;
gboolean instring;
gboolean intag;
gboolean diese;
char *home_directory;

struct widsheet
  {
	  GtkWidget *table;
	  GtkWidget *vscrollbar;
	  GtkWidget *hscrollbar;
	  GtkWidget *text;
	  char fichier[255];
	  char chemin[255];
	  char type[20];
	  /*
	   * 0= read only, 1=read/write since write is unuseful 
	   */
	  gboolean acces;
	  gboolean new;
	  gboolean inprj;
	  gboolean saved;
  };

struct proje
  {
	  char path[255];
  };

/*
 * allocate file variables : 150 files max, (it can be increased but... our memory is limited)
 */
struct widsheet sheet[150];
struct proje projectfiles[150];

/*
 * Global variables
 */
struct {
	int argc;
	char **argv;
	gboolean tips_window_displayed;
} global;
